@@ -9,6 +9,15 @@ import cv2
 default_onnx_path = f'{os.path.dirname(__file__)}/centerface.onnx'
 
 
+def ensure_rgb(img: np.ndarray) -> np.ndarray:
+    """Convert input image to RGB if it is in RGBA or L format"""
+    if img.ndim == 2:  # 1-channel grayscale -> RGB
+        img = cv2.cvtColor(img, cv2.COLOR_GRAY2RGB)
+    elif img.shape[2] == 4:  # 4-channel RGBA -> RGB
+        img = cv2.cvtColor(img, cv2.COLOR_RGBA2RGB)
+    return img
+
+
 class CenterFace:
     def __init__(self, onnx_path=None, in_shape=None, backend='auto'):
         self.in_shape = in_shape
@@ -41,7 +50,7 @@ class CenterFace:
 
             static_model = onnx.load(onnx_path)
             dyn_model = self.dynamicize_shapes(static_model)
-            self.sess = onnxruntime.InferenceSession(dyn_model.SerializeToString())
+            self.sess = onnxruntime.InferenceSession(dyn_model.SerializeToString(), providers=['CUDAExecutionProvider', 'CPUExecutionProvider'])
 
             preferred_provider = self.sess.get_providers()[0]
             preferred_device = 'GPU' if preferred_provider.startswith('CUDA') else 'CPU'
@@ -71,6 +80,7 @@ class CenterFace:
         return dyn_model
 
     def __call__(self, img, threshold=0.5):
+        img = ensure_rgb(img)
         self.orig_shape = img.shape[:2]
         if self.in_shape is None:
             self.in_shape = self.orig_shape[::-1]
