@@ -101,7 +101,7 @@ def cam_read_iter(reader):
 def video_detect(
         ipath: str,
         opath: str,
-        centerface: str,
+        centerface: CenterFace,
         threshold: float,
         enable_preview: bool,
         cam: bool,
@@ -114,7 +114,11 @@ def video_detect(
         replaceimg = None
 ):
     try:
-        reader: imageio.plugins.ffmpeg.FfmpegFormat.Reader = imageio.get_reader(ipath)
+        if 'fps' in ffmpeg_config:
+            reader: imageio.plugins.ffmpeg.FfmpegFormat.Reader = imageio.get_reader(ipath, fps=ffmpeg_config['fps'])
+        else:
+            reader: imageio.plugins.ffmpeg.FfmpegFormat.Reader = imageio.get_reader(ipath)
+
         meta = reader.get_meta_data()
         _ = meta['size']
     except:
@@ -136,8 +140,12 @@ def video_detect(
         bar = tqdm.tqdm(dynamic_ncols=True, total=nframes)
 
     if opath is not None:
+        _ffmpeg_config = ffmpeg_config.copy()
+        if not 'fps' in _ffmpeg_config:
+            #  If fps is not explicitly set in ffmpeg_config, use source video fps value
+            _ffmpeg_config['fps'] = meta['fps']
         writer: imageio.plugins.ffmpeg.FfmpegFormat.Writer = imageio.get_writer(
-            opath, format='FFMPEG', mode='I', fps=meta['fps'], **ffmpeg_config
+            opath, format='FFMPEG', mode='I', **_ffmpeg_config
         )
 
     for frame in read_iter:
@@ -168,7 +176,7 @@ def video_detect(
 def image_detect(
         ipath: str,
         opath: str,
-        centerface: str,
+        centerface: CenterFace,
         threshold: float,
         replacewith: str,
         mask_scale: float,
@@ -304,7 +312,9 @@ def main():
         if os.path.isdir(path):
             for file in os.listdir(path):
                 ipaths.append(os.path.join(path,file))
-        elif os.path.isfile(path):
+        else:
+            # Either a path to a regular file, the special 'cam' shortcut
+            # or an invalid path. The latter two cases are handled below.
             ipaths.append(path)
 
     base_opath = args.output
